@@ -11,7 +11,7 @@ use Type::Utils   -all;
 
 use Data::Object;
 
-our $VERSION = '0.04'; # VERSION
+our $VERSION = '0.05'; # VERSION
 
 extends 'Types::Standard';
 extends 'Types::Common::Numeric';
@@ -19,15 +19,6 @@ extends 'Types::Common::String';
 
 my $registry = __PACKAGE__->meta;
 
-my $constraint_name;
-my $constraint_code;
-
-my $coercion_name;
-my $coercion_code;
-
-my $explanation_name;
-my $explanation_code;
-
 sub DECLARE {
     my ($name, %opts) = @_;
 
@@ -103,8 +94,8 @@ sub DECLARE {
     return $type;
 }
 
-$constraint_name = 'constraint_generator';
-$constraint_code = sub {
+my $array_constraint_name = 'constraint_generator';
+my $array_constraint_code = sub {
     my $param = @_ ? Types::TypeTiny::to_TypeTiny(shift) :
         return $registry->get_type('ArrayObject');
 
@@ -121,8 +112,8 @@ $constraint_code = sub {
     }
 };
 
-$coercion_name = 'coercion_generator';
-$coercion_code = sub {
+my $array_coercion_name = 'coercion_generator';
+my $array_coercion_code = sub {
     my ($parent, $child, $param) = @_;
 
     return $parent->coercion unless $param->has_coercion;
@@ -148,8 +139,8 @@ $coercion_code = sub {
     return $c;
 };
 
-$explanation_name = 'deep_explanation';
-$explanation_code = sub {
+my $array_explanation_name = 'deep_explanation';
+my $array_explanation_code = sub {
     my ($type, $value, $varname) = @_;
     my $param = $type->parameters->[0];
 
@@ -166,9 +157,9 @@ $explanation_code = sub {
 };
 
 my @with_array_extras = (
-    $constraint_name  => $constraint_code,
-    $coercion_name    => $coercion_code,
-    $explanation_name => $explanation_code,
+    $array_constraint_name  => $array_constraint_code,
+    $array_coercion_name    => $array_coercion_code,
+    $array_explanation_name => $array_explanation_code,
 );
 
 DECLARE ["ArrayObj", "ArrayObject"] => (@with_array_extras,
@@ -192,8 +183,8 @@ DECLARE ["FloatObj", "FloatObject"] => (
     coerce => ["Str", "Num", "LaxNum"],
 );
 
-$constraint_name = 'constraint_generator';
-$constraint_code = sub {
+my $hash_constraint_name = 'constraint_generator';
+my $hash_constraint_code = sub {
     my $param = @_ ? Types::TypeTiny::to_TypeTiny(shift) :
         return $registry->get_type('HashObject');
 
@@ -210,8 +201,8 @@ $constraint_code = sub {
     }
 };
 
-$coercion_name = 'coercion_generator';
-$coercion_code = sub {
+my $hash_coercion_name = 'coercion_generator';
+my $hash_coercion_code = sub {
     my ($parent, $child, $param) = @_;
 
     return $parent->coercion unless $param->has_coercion;
@@ -237,8 +228,8 @@ $coercion_code = sub {
     return $c;
 };
 
-$explanation_name = 'deep_explanation';
-$explanation_code = sub {
+my $hash_explanation_name = 'deep_explanation';
+my $hash_explanation_code = sub {
     my ($type, $value, $varname) = @_;
     my $param = $type->parameters->[0];
 
@@ -254,8 +245,8 @@ $explanation_code = sub {
     return;
 };
 
-my $overrides_name = 'my_methods';
-my $overrides_opts = {
+my $hash_overrides_name = 'my_methods';
+my $hash_overrides_opts = {
     hashref_allows_key => sub {
         my ($self, $key) = @_;
         $registry->get_type('Str')->check($key);
@@ -276,10 +267,10 @@ my $overrides_opts = {
 };
 
 my @with_hash_extras = (
-    $constraint_name  => $constraint_code,
-    $coercion_name    => $coercion_code,
-    $explanation_name => $explanation_code,
-    $overrides_name   => $overrides_opts,
+    $hash_constraint_name  => $hash_constraint_code,
+    $hash_coercion_name    => $hash_coercion_code,
+    $hash_explanation_name => $hash_explanation_code,
+    $hash_overrides_name   => $hash_overrides_opts,
 );
 
 DECLARE ["HashObj", "HashObject"] => (@with_hash_extras,
@@ -352,7 +343,7 @@ Data::Object::Library - Data::Object Type Library for Perl 5
 
 =head1 VERSION
 
-version 0.04
+version 0.05
 
 =head1 SYNOPSIS
 
@@ -362,436 +353,436 @@ version 0.04
 
 Data::Object::Library is a L<Type::Tiny> library that extends the
 L<Types::Standard>, L<Types::Common::Numeric>, and L<Types::Common::String>
-libraries and adds additional type constraints and coercions which validate and
-transform L<Data::Object> data type objects.
+libraries and adds type constraints and coercions for L<Data::Object> objects.
 
-=head2 TYPES
+=head1 TYPES
 
-This following is a complete list of type constraints provided by this library.
-
-=over
-
-=item C<< Any >>
+=head2 Any
 
 The Any type constraint is provided by the L<Types::Standard> library. Please
-see that documentation.
+see that documentation for more information.
 
-=item C<< AnyObj >>
+=head2 AnyObj
 
 The AnyObj type constraint is provided by this library and accepts any object
-that is, or is derived from, a L<Data::Object::Universal>.
+that is, or is derived from, a L<Data::Object::Universal> object.
 
-=item C<< AnyObject >>
+=head2 AnyObject
 
 The AnyObject type constraint is provided by this library and accepts any
-object that is, or is derived from, a L<Data::Object::Universal>.
+object that is, or is derived from, a L<Data::Object::Universal> object.
 
-=item C<< ArrayObj >>
+=head2 ArrayObj
 
 The ArrayObj type constraint is provided by this library and accepts any object
-that is, or is derived from, a L<Data::Object::Array>.
+that is, or is derived from, a L<Data::Object::Array> object.
 
-=item C<< ArrayObject >>
+=head2 ArrayObject
 
 The ArrayObject type constraint is provided by this library and accepts any
-object that is, or is derived from, a L<Data::Object::Array>.
+object that is, or is derived from, a L<Data::Object::Array> object.
 
-=item C<< ArrayRef >>
+=head2 ArrayRef
 
 The ArrayRef type constraint is provided by the L<Types::Standard> library.
-Please see that documentation.
+Please see that documentation for more information.
 
-=item C<< Bool >>
+=head2 Bool
 
 The Bool type constraint is provided by the L<Types::Standard> library. Please
-see that documentation.
+see that documentation for more information.
 
-=item C<< ClassName >>
+=head2 ClassName
 
 The ClassName type constraint is provided by the L<Types::Standard> library.
-Please see that documentation.
+Please see that documentation for more information.
 
-=item C<< CodeObj >>
+=head2 CodeObj
 
 The CodeObj type constraint is provided by this library and accepts any object
-that is, or is derived from, a L<Data::Object::Code>.
+that is, or is derived from, a L<Data::Object::Code> object.
 
-=item C<< CodeObject >>
+=head2 CodeObject
 
 The CodeObject type constraint is provided by this library and accepts any
-object that is, or is derived from, a L<Data::Object::Code>.
+object that is, or is derived from, a L<Data::Object::Code> object.
 
-=item C<< CodeRef >>
+=head2 CodeRef
 
 The CodeRef type constraint is provided by the L<Types::Standard> library.
-Please see that documentation.
+Please see that documentation for more information.
 
-=item C<< ConsumerOf >>
+=head2 ConsumerOf
 
 The ConsumerOf type constraint is provided by the L<Types::Standard> library.
-Please see that documentation.
+Please see that documentation for more information.
 
-=item C<< Defined >>
+=head2 Defined
 
 The Defined type constraint is provided by the L<Types::Standard> library.
-Please see that documentation.
+Please see that documentation for more information.
 
-=item C<< Dict >>
+=head2 Dict
 
 The Dict type constraint is provided by the L<Types::Standard> library. Please
-see that documentation.
+see that documentation for more information.
 
-=item C<< Enum >>
+=head2 Enum
 
 The Enum type constraint is provided by the L<Types::Standard> library. Please
-see that documentation.
+see that documentation for more information.
 
-=item C<< FileHandle >>
+=head2 FileHandle
 
 The FileHandle type constraint is provided by the L<Types::Standard> library.
-Please see that documentation.
+Please see that documentation for more information.
 
-=item C<< FloatObj >>
+=head2 FloatObj
 
 The FloatObj type constraint is provided by this library and accepts any object
-that is, or is derived from, a L<Data::Object::Float>.
+that is, or is derived from, a L<Data::Object::Float> object.
 
-=item C<< FloatObject >>
+=head2 FloatObject
 
 The FloatObject type constraint is provided by this library and accepts any
-object that is, or is derived from, a L<Data::Object::Float>.
+object that is, or is derived from, a L<Data::Object::Float> object.
 
-=item C<< GlobRef >>
+=head2 GlobRef
 
 The GlobRef type constraint is provided by the L<Types::Standard> library.
-Please see that documentation.
+Please see that documentation for more information.
 
-=item C<< HasMethods >>
+=head2 HasMethods
 
 The HasMethods type constraint is provided by the L<Types::Standard> library.
-Please see that documentation.
+Please see that documentation for more information.
 
-=item C<< HashObj >>
+=head2 HashObj
 
 The HashObj type constraint is provided by this library and accepts any object
-that is, or is derived from, a L<Data::Object::Hash>.
+that is, or is derived from, a L<Data::Object::Hash> object.
 
-=item C<< HashObject >>
+=head2 HashObject
 
 The HashObject type constraint is provided by this library and accepts any
-object that is, or is derived from, a L<Data::Object::Hash>.
+object that is, or is derived from, a L<Data::Object::Hash> object.
 
-=item C<< HashRef >>
+=head2 HashRef
 
 The HashRef type constraint is provided by the L<Types::Standard> library.
-Please see that documentation.
+Please see that documentation for more information.
 
-=item C<< InstanceOf >>
+=head2 InstanceOf
 
 The InstanceOf type constraint is provided by the L<Types::Standard> library.
-Please see that documentation.
+Please see that documentation for more information.
 
-=item C<< Int >>
+=head2 Int
 
 The Int type constraint is provided by the L<Types::Standard> library. Please
-see that documentation.
+see that documentation for more information.
 
-=item C<< IntObj >>
+=head2 IntObj
 
 The IntObj type constraint is provided by this library and accepts any object
-that is, or is derived from, a L<Data::Object::Integer>.
+that is, or is derived from, a L<Data::Object::Integer> object.
 
-=item C<< IntObject >>
+=head2 IntObject
 
 The IntObject type constraint is provided by this library and accepts any
-object that is, or is derived from, a L<Data::Object::Integer>.
+object that is, or is derived from, a L<Data::Object::Integer> object.
 
-=item C<< IntegerObj >>
+=head2 IntegerObj
 
 The IntegerObj type constraint is provided by this library and accepts any
-object that is, or is derived from, a L<Data::Object::Integer>.
+object that is, or is derived from, a L<Data::Object::Integer> object.
 
-=item C<< IntegerObject >>
+=head2 IntegerObject
 
 The IntegerObject type constraint is provided by this library and accepts any
-object that is, or is derived from, a L<Data::Object::Integer>.
+object that is, or is derived from, a L<Data::Object::Integer> object.
 
-=item C<< Item >>
+=head2 Item
 
 The Item type constraint is provided by the L<Types::Standard> library. Please
-see that documentation.
+see that documentation for more information.
 
-=item C<< LaxNum >>
+=head2 LaxNum
 
 The LaxNum type constraint is provided by the L<Types::Standard> library.
-Please see that documentation.
+Please see that documentation for more information.
 
-=item C<< LowerCaseSimpleStr >>
+=head2 LowerCaseSimpleStr
 
 The LowerCaseSimpleStr type constraint is provided by the
-L<Types::Common::String> library. Please see that documentation.
+L<Types::Common::String> library. Please see that documentation for more
+information.
 
-=item C<< LowerCaseStr >>
+=head2 LowerCaseStr
 
 The LowerCaseStr type constraint is provided by the L<Types::Common::String>
-library. Please see that documentation.
+library. Please see that documentation for more information.
 
-=item C<< Map >>
+=head2 Map
 
 The Map type constraint is provided by the L<Types::Standard> library. Please
-see that documentation.
+see that documentation for more information.
 
-=item C<< Maybe >>
+=head2 Maybe
 
 The Maybe type constraint is provided by the L<Types::Standard> library. Please
-see that documentation.
+see that documentation for more information.
 
-=item C<< NegativeInt >>
+=head2 NegativeInt
 
 The NegativeInt type constraint is provided by the L<Types::Common::Numeric>
-library. Please see that documentation.
+library. Please see that documentation for more information.
 
-=item C<< NegativeNum >>
+=head2 NegativeNum
 
 The NegativeNum type constraint is provided by the L<Types::Common::Numeric>
-library. Please see that documentation.
+library. Please see that documentation for more information.
 
-=item C<< NegativeOrZeroInt >>
+=head2 NegativeOrZeroInt
 
 The NegativeOrZeroInt type constraint is provided by the
-L<Types::Common::Numeric> library. Please see that documentation.
+L<Types::Common::Numeric> library. Please see that documentation for more
+information.
 
-=item C<< NegativeOrZeroNum >>
+=head2 NegativeOrZeroNum
 
 The NegativeOrZeroNum type constraint is provided by the
-L<Types::Common::Numeric> library. Please see that documentation.
+L<Types::Common::Numeric> library. Please see that documentation for more
+information.
 
-=item C<< NonEmptySimpleStr >>
+=head2 NonEmptySimpleStr
 
 The NonEmptySimpleStr type constraint is provided by the
-L<Types::Common::String> library. Please see that documentation.
+L<Types::Common::String> library. Please see that documentation for more
+information.
 
-=item C<< NonEmptyStr >>
+=head2 NonEmptyStr
 
 The NonEmptyStr type constraint is provided by the L<Types::Standard> library.
-Please see that documentation.
+Please see that documentation for more information.
 
-=item C<< Num >>
+=head2 Num
 
 The Num type constraint is provided by the L<Types::Standard> library. Please
-see that documentation.
+see that documentation for more information.
 
-=item C<< NumObj >>
+=head2 NumObj
 
 The NumObj type constraint is provided by this library and accepts any object
-that is, or is derived from, a L<Data::Object::Number>.
+that is, or is derived from, a L<Data::Object::Number> object.
 
-=item C<< NumObject >>
+=head2 NumObject
 
 The NumObject type constraint is provided by this library and accepts any
-object that is, or is derived from, a L<Data::Object::Number>.
+object that is, or is derived from, a L<Data::Object::Number> object.
 
-=item C<< NumberObj >>
+=head2 NumberObj
 
 The NumberObj type constraint is provided by this library and accepts any
-object that is, or is derived from, a L<Data::Object::Number>.
+object that is, or is derived from, a L<Data::Object::Number> object.
 
-=item C<< NumberObject >>
+=head2 NumberObject
 
 The NumberObject type constraint is provided by this library and accepts any
-object that is, or is derived from, a L<Data::Object::Number>.
+object that is, or is derived from, a L<Data::Object::Number> object.
 
-=item C<< NumericCode >>
+=head2 NumericCode
 
 The NumericCode type constraint is provided by the L<Types::Common::String>
-library. Please see that documentation.
+library. Please see that documentation for more information.
 
-=item C<< Object >>
+=head2 Object
 
 The Object type constraint is provided by the L<Types::Standard> library.
-Please see that documentation.
+Please see that documentation for more information.
 
-=item C<< OptList >>
+=head2 OptList
 
 The OptList type constraint is provided by the L<Types::Standard> library.
-Please see that documentation.
+Please see that documentation for more information.
 
-=item C<< Optional >>
+=head2 Optional
 
 The Optional type constraint is provided by the L<Types::Standard> library.
-Please see that documentation.
+Please see that documentation for more information.
 
-=item C<< Overload >>
+=head2 Overload
 
 The Overload type constraint is provided by the L<Types::Standard> library.
-Please see that documentation.
+Please see that documentation for more information.
 
-=item C<< Password >>
+=head2 Password
 
 The Password type constraint is provided by the L<Types::Standard> library.
-Please see that documentation.
+Please see that documentation for more information.
 
-=item C<< PositiveInt >>
+=head2 PositiveInt
 
 The PositiveInt type constraint is provided by the L<Types::Common::Numeric>
-library. Please see that documentation.
+library. Please see that documentation for more information.
 
-=item C<< PositiveNum >>
+=head2 PositiveNum
 
 The PositiveNum type constraint is provided by the L<Types::Common::Numeric>
-library. Please see that documentation.
+library. Please see that documentation for more information.
 
-=item C<< PositiveOrZeroInt >>
+=head2 PositiveOrZeroInt
 
 The PositiveOrZeroInt type constraint is provided by the
-L<Types::Common::Numeric> library. Please see that documentation.
+L<Types::Common::Numeric> library. Please see that documentation for more
+information.
 
-=item C<< PositiveOrZeroNum >>
+=head2 PositiveOrZeroNum
 
 The PositiveOrZeroNum type constraint is provided by the
-L<Types::Common::Numeric> library. Please see that documentation.
+L<Types::Common::Numeric> library. Please see that documentation for more
+information.
 
-=item C<< Ref >>
+=head2 Ref
 
 The Ref type constraint is provided by the L<Types::Standard> library. Please
-see that documentation.
+see that documentation for more information.
 
-=item C<< RegexpObj >>
+=head2 RegexpObj
 
 The RegexpObj type constraint is provided by this library and accepts any
-object that is, or is derived from, a L<Data::Object::Regexp>.
+object that is, or is derived from, a L<Data::Object::Regexp> object.
 
-=item C<< RegexpObject >>
+=head2 RegexpObject
 
 The RegexpObject type constraint is provided by this library and accepts any
-object that is, or is derived from, a L<Data::Object::Regexp>.
+object that is, or is derived from, a L<Data::Object::Regexp> object.
 
-=item C<< RegexpRef >>
+=head2 RegexpRef
 
 The RegexpRef type constraint is provided by the L<Types::Standard> library.
-Please see that documentation.
+Please see that documentation for more information.
 
-=item C<< RoleName >>
+=head2 RoleName
 
 The RoleName type constraint is provided by the L<Types::Standard> library.
-Please see that documentation.
+Please see that documentation for more information.
 
-=item C<< ScalarObj >>
+=head2 ScalarObj
 
 The ScalarObj type constraint is provided by this library and accepts any
-object that is, or is derived from, a L<Data::Object::Scalar>.
+object that is, or is derived from, a L<Data::Object::Scalar> object.
 
-=item C<< ScalarObject >>
+=head2 ScalarObject
 
 The ScalarObject type constraint is provided by this library and accepts any
-object that is, or is derived from, a L<Data::Object::Scalar>.
+object that is, or is derived from, a L<Data::Object::Scalar> object.
 
-=item C<< ScalarRef >>
+=head2 ScalarRef
 
 The ScalarRef type constraint is provided by the L<Types::Standard> library.
-Please see that documentation.
+Please see that documentation for more information.
 
-=item C<< SimpleStr >>
+=head2 SimpleStr
 
 The SimpleStr type constraint is provided by the L<Types::Common::String>
-library. Please see that documentation.
+library. Please see that documentation for more information.
 
-=item C<< SingleDigit >>
+=head2 SingleDigit
 
 The SingleDigit type constraint is provided by the L<Types::Common::Numeric>
-library. Please see that documentation.
+library. Please see that documentation for more information.
 
-=item C<< Str >>
+=head2 Str
 
 The Str type constraint is provided by the L<Types::Standard> library. Please
-see that documentation.
+see that documentation for more information.
 
-=item C<< StrMatch >>
+=head2 StrMatch
 
 The StrMatch type constraint is provided by the L<Types::Standard> library.
-Please see that documentation.
+Please see that documentation for more information.
 
-=item C<< StrObj >>
+=head2 StrObj
 
 The StrObj type constraint is provided by this library and accepts any object
-that is, or is derived from, a L<Data::Object::String>.
+that is, or is derived from, a L<Data::Object::String> object.
 
-=item C<< StrObject >>
+=head2 StrObject
 
 The StrObject type constraint is provided by this library and accepts any
-object that is, or is derived from, a L<Data::Object::String>.
+object that is, or is derived from, a L<Data::Object::String> object.
 
-=item C<< StrictNum >>
+=head2 StrictNum
 
 The StrictNum type constraint is provided by the L<Types::Standard> library.
-Please see that documentation.
+Please see that documentation for more information.
 
-=item C<< StringObj >>
+=head2 StringObj
 
 The StringObj type constraint is provided by this library and accepts any
-object that is, or is derived from, a L<Data::Object::String>.
+object that is, or is derived from, a L<Data::Object::String> object.
 
-=item C<< StringObject >>
+=head2 StringObject
 
 The StringObject type constraint is provided by this library and accepts any
-object that is, or is derived from, a L<Data::Object::String>.
+object that is, or is derived from, a L<Data::Object::String> object.
 
-=item C<< StrongPassword >>
+=head2 StrongPassword
 
 The StrongPassword type constraint is provided by the L<Types::Common::String>
-library. Please see that documentation.
+library. Please see that documentation for more information.
 
-=item C<< Tied >>
+=head2 Tied
 
 The Tied type constraint is provided by the L<Types::Standard> library. Please
-see that documentation.
+see that documentation for more information.
 
-=item C<< Tuple >>
+=head2 Tuple
 
 The Tuple type constraint is provided by the L<Types::Standard> library. Please
-see that documentation.
+see that documentation for more information.
 
-=item C<< Undef >>
+=head2 Undef
 
 The Undef type constraint is provided by the L<Types::Standard> library. Please
-see that documentation.
+see that documentation for more information.
 
-=item C<< UndefObj >>
+=head2 UndefObj
 
 The UndefObj type constraint is provided by this library and accepts any object
-that is, or is derived from, a L<Data::Object::Undef>.
+that is, or is derived from, a L<Data::Object::Undef> object.
 
-=item C<< UndefObject >>
+=head2 UndefObject
 
 The UndefObject type constraint is provided by this library and accepts any
-object that is, or is derived from, a L<Data::Object::Undef>.
+object that is, or is derived from, a L<Data::Object::Undef> object.
 
-=item C<< UniversalObj >>
+=head2 UniversalObj
 
 The UniversalObj type constraint is provided by this library and accepts any
-object that is, or is derived from, a L<Data::Object::Universal>.
+object that is, or is derived from, a L<Data::Object::Universal> object.
 
-=item C<< UniversalObject >>
+=head2 UniversalObject
 
 The UniversalObject type constraint is provided by this library and accepts any
-object that is, or is derived from, a L<Data::Object::Universal>.
+object that is, or is derived from, a L<Data::Object::Universal> object.
 
-=item C<< UpperCaseSimpleStr >>
+=head2 UpperCaseSimpleStr
 
 The UpperCaseSimpleStr type constraint is provided by the
-L<Types::Common::String> library. Please see that documentation.
+L<Types::Common::String> library. Please see that documentation for more
+information.
 
-=item C<< UpperCaseStr >>
+=head2 UpperCaseStr
 
 The UpperCaseStr type constraint is provided by the L<Types::Common::String>
-library. Please see that documentation.
+library. Please see that documentation for more information.
 
-=item C<< Value >>
+=head2 Value
 
 The Value type constraint is provided by the L<Types::Standard> library. Please
-see that documentation.
-
-=back
+see that documentation for more information.
 
 =head1 AUTHOR
 
